.. _renderers:

=========
Renderers
=========

The section contains an overview of all the plots
that are included in cgatreport.

.. toctree::
   :maxdepth: 2

   GalleryTables.rst
   GalleryMatrices.rst
   GalleryBarplots.rst
   GalleryPiePlots.rst
   GalleryLinePlots.rst
   GalleryHistograms.rst
   GalleryBoxPlots.rst
   GalleryViolinPlots.rst
   GalleryDensityPlots.rst
   GalleryScatterPlots.rst
   GalleryVenn.rst
   GalleryGGPlot.rst
   GalleryConfig.rst
   GalleryStatus.rst
   GalleryGallery.rst
   GalleryUser.rst
   GalleryRPlots.rst
   GalleryDebug.rst
   GalleryDataframe.rst
   GalleryLegends.rst
   GalleryOptions.rst
   GalleryBokeh.rst
